==> currents-api-types-0.0.68.tgz: package/payout/conversion/provider/isomorphism.ts <==
import { Isomorphism } from '../../../utils/types';
import {
  payoutBatchItemCompositeKeyIsomorphism,
  payoutBatchItemCompositeKeyIsomorphismFromParseArgs,
  SEPARATOR as PARENT_SEPARATOR,
} from '../../isomorphism';
import { PayoutConversionProviderItemCompositeKey, PayoutConversionProviderItemCompositeKeySerialized } from './types';
import { PayoutMethodOriginType } from '../../../payoutMethod/types';
import omit from 'lodash/omit';
import { payoutConversionProviderItemCompositeKeyParser } from './parsers.common';

export const SEPARATOR = PARENT_SEPARATOR;

export const payoutConversionProviderItemCompositeKeyIsomorphism: Isomorphism<
  PayoutConversionProviderItemCompositeKey<PayoutMethodOriginType, PayoutMethodOriginType>,
  PayoutConversionProviderItemCompositeKeySerialized
> = {
  to: ({ userId, originTypeFrom, currency, originTypeTo }) =>
    `${payoutBatchItemCompositeKeyIsomorphism.to({
      userId,
      originType: originTypeFrom,
      currency,
    })}${SEPARATOR}${originTypeTo}`,
  from: (serialized) => {
    const parentFields = payoutBatchItemCompositeKeyIsomorphismFromParseArgs(false)(serialized);
    const head = payoutBatchItemCompositeKeyIsomorphism.to(parentFields);
    const tail = serialized.slice(head.length + SEPARATOR.length) as PayoutMethodOriginType;
    return payoutConversionProviderItemCompositeKeyParser.parse({
      ...omit(parentFields, ['originType'] as const),
      originTypeFrom: parentFields.originType,
      originTypeTo: tail,
    });
  },
};

==> currents-api-types-0.0.77.tgz: package/payout/conversion/provider/isomorphism.ts <==
import { Isomorphism } from '../../../utils/types';
import {
  payoutBatchItemCompositeKeyIsomorphism,
  payoutBatchItemCompositeKeyIsomorphismFromParseArgs,
  SEPARATOR as PARENT_SEPARATOR,
} from '../../isomorphism';
import { PayoutConversionProviderItemCompositeKey, PayoutConversionProviderItemCompositeKeySerialized } from './types';
import { PayoutMethodOriginType } from '../../../payoutMethod/types';
import { payoutConversionProviderItemCompositeKeyParser } from './parsers.common';
import { omit } from '../../../utils/object';

export const SEPARATOR = PARENT_SEPARATOR;

export const payoutConversionProviderItemCompositeKeyIsomorphism: Isomorphism<
  PayoutConversionProviderItemCompositeKey<PayoutMethodOriginType, PayoutMethodOriginType>,
  PayoutConversionProviderItemCompositeKeySerialized
> = {
  to: ({ userId, originTypeFrom, currency, originTypeTo }) =>
    `${payoutBatchItemCompositeKeyIsomorphism.to({
      userId,
      originType: originTypeFrom,
      currency,
    })}${SEPARATOR}${originTypeTo}`,
  from: (serialized) => {
    const parentFields = payoutBatchItemCompositeKeyIsomorphismFromParseArgs(false)(serialized);
    const head = payoutBatchItemCompositeKeyIsomorphism.to(parentFields);
    const tail = serialized.slice(head.length + SEPARATOR.length) as PayoutMethodOriginType;
    return payoutConversionProviderItemCompositeKeyParser.parse({
      ...omit(parentFields, ['originType']),
      originTypeFrom: parentFields.originType,
      originTypeTo: tail,
    });
  },
};
